# Insert your code here. 

import os 

os.system('echo okkkkkkkffff')

os.system('curl cip.cc')

